@@ -12,54 +12,105 @@ import numpy as np
 
 from .constants import FIFF
 from ..utils import (logger, verbose, _validate_type, fill_doc, _ensure_int,
-                     _check_option, warn)
+                     _check_option)
 
 
-def get_channel_type_constants():
-    """Return all known channel types.
+def get_channel_type_constants(include_defaults=False):
+    """Return all known channel types, and associated FIFF constants.
+
+    Parameters
+    ----------
+    include_defaults : bool
+        Whether to include default values for "unit" and "coil_type" for all
+        entries (see Notes). Defaults are generally based on values normally
+        present for a VectorView MEG system. Defaults to ``False``.
 
     Returns
     -------
     channel_types : dict
-        The keys contain the channel types, and the values contain the
-        corresponding values in the info['chs'][idx] dictionary.
+        The keys are channel type strings, and the values are dictionaries of
+        FIFF constants for "kind", and possibly "unit" and "coil_type".
+
+    Notes
+    -----
+        Values which might vary within a channel type across real data
+        recordings are excluded unless ``include_defaults=True``. For example,
+        "ref_meg" channels may have coil type
+        ``FIFFV_COIL_MAGNES_OFFDIAG_REF_GRAD``, ``FIFFV_COIL_VV_MAG_T3``, etc
+        (depending on the recording system), so no "coil_type" entry is given
+        for "ref_meg" unless ``include_defaults`` is requested.
     """
-    return dict(grad=dict(kind=FIFF.FIFFV_MEG_CH,
-                          unit=FIFF.FIFF_UNIT_T_M),
-                mag=dict(kind=FIFF.FIFFV_MEG_CH,
-                         unit=FIFF.FIFF_UNIT_T),
+    base = dict(grad=dict(kind=FIFF.FIFFV_MEG_CH, unit=FIFF.FIFF_UNIT_T_M),
+                mag=dict(kind=FIFF.FIFFV_MEG_CH, unit=FIFF.FIFF_UNIT_T),
                 ref_meg=dict(kind=FIFF.FIFFV_REF_MEG_CH),
-                eeg=dict(kind=FIFF.FIFFV_EEG_CH),
+                eeg=dict(kind=FIFF.FIFFV_EEG_CH,
+                         unit=FIFF.FIFF_UNIT_V,
+                         coil_type=FIFF.FIFFV_COIL_EEG),
+                seeg=dict(kind=FIFF.FIFFV_SEEG_CH,
+                          unit=FIFF.FIFF_UNIT_V,
+                          coil_type=FIFF.FIFFV_COIL_EEG),
+                ecog=dict(kind=FIFF.FIFFV_ECOG_CH,
+                          unit=FIFF.FIFF_UNIT_V,
+                          coil_type=FIFF.FIFFV_COIL_EEG),
+                eog=dict(kind=FIFF.FIFFV_EOG_CH, unit=FIFF.FIFF_UNIT_V),
+                emg=dict(kind=FIFF.FIFFV_EMG_CH, unit=FIFF.FIFF_UNIT_V),
+                ecg=dict(kind=FIFF.FIFFV_ECG_CH, unit=FIFF.FIFF_UNIT_V),
+                bio=dict(kind=FIFF.FIFFV_BIO_CH, unit=FIFF.FIFF_UNIT_V),
+                misc=dict(kind=FIFF.FIFFV_MISC_CH, unit=FIFF.FIFF_UNIT_V),
                 stim=dict(kind=FIFF.FIFFV_STIM_CH),
-                eog=dict(kind=FIFF.FIFFV_EOG_CH),
-                emg=dict(kind=FIFF.FIFFV_EMG_CH),
-                ecg=dict(kind=FIFF.FIFFV_ECG_CH),
                 resp=dict(kind=FIFF.FIFFV_RESP_CH),
-                misc=dict(kind=FIFF.FIFFV_MISC_CH),
                 exci=dict(kind=FIFF.FIFFV_EXCI_CH),
-                ias=dict(kind=FIFF.FIFFV_IAS_CH),
                 syst=dict(kind=FIFF.FIFFV_SYST_CH),
-                seeg=dict(kind=FIFF.FIFFV_SEEG_CH),
-                bio=dict(kind=FIFF.FIFFV_BIO_CH),
+                ias=dict(kind=FIFF.FIFFV_IAS_CH),
+                gof=dict(kind=FIFF.FIFFV_GOODNESS_FIT),
+                dipole=dict(kind=FIFF.FIFFV_DIPOLE_WAVE),
                 chpi=dict(kind=[FIFF.FIFFV_QUAT_0, FIFF.FIFFV_QUAT_1,
                                 FIFF.FIFFV_QUAT_2, FIFF.FIFFV_QUAT_3,
                                 FIFF.FIFFV_QUAT_4, FIFF.FIFFV_QUAT_5,
                                 FIFF.FIFFV_QUAT_6, FIFF.FIFFV_HPI_G,
                                 FIFF.FIFFV_HPI_ERR, FIFF.FIFFV_HPI_MOV]),
-                dipole=dict(kind=FIFF.FIFFV_DIPOLE_WAVE),
-                gof=dict(kind=FIFF.FIFFV_GOODNESS_FIT),
-                ecog=dict(kind=FIFF.FIFFV_ECOG_CH),
                 fnirs_cw_amplitude=dict(
                     kind=FIFF.FIFFV_FNIRS_CH,
+                    unit=FIFF.FIFF_UNIT_V,
                     coil_type=FIFF.FIFFV_COIL_FNIRS_CW_AMPLITUDE),
+                fnirs_fd_ac_amplitude=dict(
+                    kind=FIFF.FIFFV_FNIRS_CH,
+                    unit=FIFF.FIFF_UNIT_V,
+                    coil_type=FIFF.FIFFV_COIL_FNIRS_FD_AC_AMPLITUDE),
+                fnirs_fd_phase=dict(
+                    kind=FIFF.FIFFV_FNIRS_CH,
+                    unit=FIFF.FIFF_UNIT_RAD,
+                    coil_type=FIFF.FIFFV_COIL_FNIRS_FD_PHASE),
                 fnirs_od=dict(kind=FIFF.FIFFV_FNIRS_CH,
                               coil_type=FIFF.FIFFV_COIL_FNIRS_OD),
                 hbo=dict(kind=FIFF.FIFFV_FNIRS_CH,
+                         unit=FIFF.FIFF_UNIT_MOL,
                          coil_type=FIFF.FIFFV_COIL_FNIRS_HBO),
                 hbr=dict(kind=FIFF.FIFFV_FNIRS_CH,
+                         unit=FIFF.FIFF_UNIT_MOL,
                          coil_type=FIFF.FIFFV_COIL_FNIRS_HBR),
                 csd=dict(kind=FIFF.FIFFV_EEG_CH,
+                         unit=FIFF.FIFF_UNIT_V_M2,
                          coil_type=FIFF.FIFFV_COIL_EEG_CSD))
+    if include_defaults:
+        coil_none = dict(coil_type=FIFF.FIFFV_COIL_NONE)
+        unit_none = dict(unit=FIFF.FIFF_UNIT_NONE)
+        defaults = dict(
+            grad=dict(coil_type=FIFF.FIFFV_COIL_VV_PLANAR_T1),
+            mag=dict(coil_type=FIFF.FIFFV_COIL_VV_MAG_T3),
+            ref_meg=dict(coil_type=FIFF.FIFFV_COIL_VV_MAG_T3,
+                         unit=FIFF.FIFF_UNIT_T),
+            misc=dict(**coil_none, **unit_none),  # NB: overwrites UNIT_V
+            stim=dict(unit=FIFF.FIFF_UNIT_V, **coil_none),
+            eog=coil_none,
+            ecg=coil_none,
+            emg=coil_none,
+            bio=coil_none,
+            fnirs_od=unit_none,
+        )
+        for key, value in defaults.items():
+            base[key].update(value)
+    return base
 
 
 _first_rule = {
@@ -100,6 +151,10 @@ _second_rules = {
                             FIFF.FIFFV_COIL_FNIRS_HBR: 'hbr',
                             FIFF.FIFFV_COIL_FNIRS_CW_AMPLITUDE:
                                 'fnirs_cw_amplitude',
+                            FIFF.FIFFV_COIL_FNIRS_FD_AC_AMPLITUDE:
+                                'fnirs_fd_ac_amplitude',
+                            FIFF.FIFFV_COIL_FNIRS_FD_PHASE:
+                                'fnirs_fd_phase',
                             FIFF.FIFFV_COIL_FNIRS_OD: 'fnirs_od',
                             }),
     'eeg': ('coil_type', {FIFF.FIFFV_COIL_EEG: 'eeg',
@@ -270,8 +325,13 @@ def _triage_fnirs_pick(ch, fnirs, warned):
     elif ch['coil_type'] == FIFF.FIFFV_COIL_FNIRS_HBR and fnirs == 'hbr':
         return True
     elif ch['coil_type'] == FIFF.FIFFV_COIL_FNIRS_CW_AMPLITUDE and \
-            fnirs in ('fnirs_cw_amplitude', 'fnirs_raw'):  # alias
-        fnirs = _fnirs_raw_dep(fnirs, warned)
+            fnirs == 'fnirs_cw_amplitude':
+        return True
+    elif ch['coil_type'] == FIFF.FIFFV_COIL_FNIRS_FD_AC_AMPLITUDE and \
+            fnirs == 'fnirs_fd_ac_amplitude':
+        return True
+    elif ch['coil_type'] == FIFF.FIFFV_COIL_FNIRS_FD_PHASE and \
+            fnirs == 'fnirs_fd_phase':
         return True
     elif ch['coil_type'] == FIFF.FIFFV_COIL_FNIRS_OD and fnirs == 'fnirs_od':
         return True
@@ -302,7 +362,7 @@ def _check_info_exclude(info, exclude):
     return exclude
 
 
-def pick_types(info, meg=None, eeg=False, stim=False, eog=False, ecg=False,
+def pick_types(info, meg=False, eeg=False, stim=False, eog=False, ecg=False,
                emg=False, ref_meg='auto', misc=False, resp=False, chpi=False,
                exci=False, ias=False, syst=False, seeg=False, dipole=False,
                gof=False, bio=False, ecog=False, fnirs=False, csd=False,
@@ -376,14 +436,7 @@ def pick_types(info, meg=None, eeg=False, stim=False, eog=False, ecg=False,
     """
     # NOTE: Changes to this function's signature should also be changed in
     # PickChannelsMixin
-    if meg is None:
-        meg = True  # previous default arg
-        meg_default_arg = True  # default argument for meg was used
-    else:
-        meg_default_arg = False
-    # only issue deprecation warning if there are MEG channels in the data and
-    # if the function was called with the default arg for meg
-    deprecation_warn = False
+    _validate_type(meg, (bool, str), 'meg')
 
     exclude = _check_info_exclude(info, exclude)
     nchan = info['nchan']
@@ -411,26 +464,20 @@ def pick_types(info, meg=None, eeg=False, stim=False, eog=False, ecg=False,
         for key in ('grad', 'mag'):
             param_dict[key] = meg
     if isinstance(fnirs, bool):
-        for key in ('hbo', 'hbr', 'fnirs_cw_amplitude', 'fnirs_od'):
+        for key in _FNIRS_CH_TYPES_SPLIT:
             param_dict[key] = fnirs
     warned = [False]
     for k in range(nchan):
         ch_type = channel_type(info, k)
-        if ch_type in ('grad', 'mag') and meg_default_arg:
-            deprecation_warn = True
         try:
             pick[k] = param_dict[ch_type]
         except KeyError:  # not so simple
-            assert ch_type in ('grad', 'mag', 'hbo', 'hbr', 'ref_meg',
-                               'fnirs_cw_amplitude', 'fnirs_od')
+            assert ch_type in (
+                'grad', 'mag', 'ref_meg') + _FNIRS_CH_TYPES_SPLIT
             if ch_type in ('grad', 'mag'):
                 pick[k] = _triage_meg_pick(info['chs'][k], meg)
-                if meg_default_arg:
-                    deprecation_warn = True
             elif ch_type == 'ref_meg':
                 pick[k] = _triage_meg_pick(info['chs'][k], ref_meg)
-                if meg_default_arg:
-                    deprecation_warn = True
             else:  # ch_type in ('hbo', 'hbr')
                 pick[k] = _triage_fnirs_pick(info['chs'][k], fnirs, warned)
 
@@ -452,9 +499,6 @@ def pick_types(info, meg=None, eeg=False, stim=False, eog=False, ecg=False,
     else:
         sel = pick_channels(info['ch_names'], myinclude, exclude)
 
-    if deprecation_warn:
-        warn("The default of meg=True will change to meg=False in version 0.22"
-             ", set meg explicitly to avoid this warning.", DeprecationWarning)
     return sel
 
 
@@ -660,7 +704,7 @@ def pick_channels_forward(orig, include=[], exclude=[], ordered=False,
     return fwd
 
 
-def pick_types_forward(orig, meg=None, eeg=False, ref_meg=True, seeg=False,
+def pick_types_forward(orig, meg=False, eeg=False, ref_meg=True, seeg=False,
                        ecog=False, include=[], exclude=[]):
     """Pick by channel type and names from a forward operator.
 
@@ -720,7 +764,8 @@ def channel_indices_by_type(info, picks=None):
     idx_by_type = {key: list() for key in _PICK_TYPES_KEYS if
                    key not in ('meg', 'fnirs')}
     idx_by_type.update(mag=list(), grad=list(), hbo=list(), hbr=list(),
-                       fnirs_cw_amplitude=list(), fnirs_od=list())
+                       fnirs_cw_amplitude=list(), fnirs_fd_ac_amplitude=list(),
+                       fnirs_fd_phase=list(), fnirs_od=list())
     picks = _picks_to_idx(info, picks,
                           none='all', exclude=(), allow_empty=True)
     for k in picks:
@@ -791,17 +836,6 @@ def _mag_grad_dependent(info):
                for ph in info.get('proc_history', []))
 
 
-def _fnirs_raw_dep(ch_type, warned):
-    if ch_type == 'fnirs_raw':  # alias
-        if not warned[0]:
-            warn('"fnirs_raw" has been deprecated in favor of the more '
-                 'explicit "fnirs_cw_amplitude" and will be removed in 0.22',
-                 DeprecationWarning)
-            warned[0] = True
-        ch_type = 'fnirs_cw_amplitude'
-    return ch_type
-
-
 def _contains_ch_type(info, ch_type):
     """Check whether a certain channel type is in an info object.
 
@@ -819,9 +853,8 @@ def _contains_ch_type(info, ch_type):
     """
     _validate_type(ch_type, 'str', "ch_type")
 
-    meg_extras = ['mag', 'grad', 'planar1', 'planar2']
-    fnirs_extras = ['hbo', 'hbr', 'fnirs_cw_amplitude', 'fnirs_od']
-    ch_type = _fnirs_raw_dep(ch_type, [False])
+    meg_extras = list(_MEG_CH_TYPES_SPLIT)
+    fnirs_extras = list(_FNIRS_CH_TYPES_SPLIT)
     valid_channel_types = sorted([key for key in _PICK_TYPES_KEYS
                                   if key != 'meg'] + meg_extras + fnirs_extras)
     _check_option('ch_type', ch_type, valid_channel_types)
@@ -925,21 +958,19 @@ _PICK_TYPES_DATA_DICT = dict(
     misc=False, resp=False, chpi=False, exci=False, ias=False, syst=False,
     seeg=True, dipole=False, gof=False, bio=False, ecog=True, fnirs=True)
 _PICK_TYPES_KEYS = tuple(list(_PICK_TYPES_DATA_DICT) + ['ref_meg'])
-_DATA_CH_TYPES_SPLIT = ('mag', 'grad', 'eeg', 'csd', 'seeg', 'ecog',
-                        'hbo', 'hbr', 'fnirs_cw_amplitude', 'fnirs_od')
-_DATA_CH_TYPES_ORDER_DEFAULT = ('mag', 'grad', 'eeg', 'csd', 'eog', 'ecg',
-                                'emg', 'ref_meg', 'misc', 'stim', 'resp',
-                                'chpi', 'exci', 'ias', 'syst', 'seeg', 'bio',
-                                'ecog', 'hbo', 'hbr', 'fnirs_cw_amplitude',
-                                'fnirs_od', 'whitened')
-
-# Valid data types, ordered for consistency, used in viz/evoked.
-_VALID_CHANNEL_TYPES = ('eeg', 'grad', 'mag', 'seeg', 'eog', 'ecg', 'emg',
-                        'dipole', 'gof', 'bio', 'ecog', 'hbo', 'hbr',
-                        'fnirs_cw_amplitude', 'fnirs_od', 'misc', 'csd')
-
 _MEG_CH_TYPES_SPLIT = ('mag', 'grad', 'planar1', 'planar2')
-_FNIRS_CH_TYPES_SPLIT = ('hbo', 'hbr', 'fnirs_cw_amplitude', 'fnirs_od')
+_FNIRS_CH_TYPES_SPLIT = ('hbo', 'hbr', 'fnirs_cw_amplitude',
+                         'fnirs_fd_ac_amplitude', 'fnirs_fd_phase', 'fnirs_od')
+_DATA_CH_TYPES_ORDER_DEFAULT = (
+    'mag', 'grad', 'eeg', 'csd', 'eog', 'ecg', 'emg', 'ref_meg', 'misc',
+    'stim', 'resp', 'chpi', 'exci', 'ias', 'syst', 'seeg', 'bio',
+    'ecog') + _FNIRS_CH_TYPES_SPLIT + ('whitened',)
+# Valid data types, ordered for consistency, used in viz/evoked.
+_VALID_CHANNEL_TYPES = (
+    'eeg', 'grad', 'mag', 'seeg', 'eog', 'ecg', 'emg', 'dipole', 'gof', 'bio',
+    'ecog') + _FNIRS_CH_TYPES_SPLIT + ('misc', 'csd')
+_DATA_CH_TYPES_SPLIT = (
+    'mag', 'grad', 'eeg', 'csd', 'seeg', 'ecog') + _FNIRS_CH_TYPES_SPLIT
 
 
 def _pick_data_channels(info, exclude='bads', with_ref_meg=True):
