@@ -12,20 +12,17 @@ import warnings
 
 import numpy as np
 
-from .utils import (tight_layout, _prepare_trellis, _select_bads,
-                    _plot_raw_onscroll, _mouse_click, _plot_annotations,
-                    _plot_raw_onkey, plt_show, _convert_psds)
-from .topomap import (_prepare_topomap_plot, plot_topomap, _hide_frame,
-                      _plot_ica_topomap, _make_head_outlines)
-from .raw import _prepare_mne_browse_raw, _plot_raw_traces
-from .epochs import _prepare_mne_browse_epochs, plot_epochs_image
+from .utils import (tight_layout, _make_event_color_dict,
+                    plt_show, _convert_psds, _compute_scalings)
+from .topomap import _plot_ica_topomap
+from .epochs import plot_epochs_image
 from .evoked import _butterfly_on_button_press, _butterfly_onpick
-from ..utils import warn, _validate_type, fill_doc
+from ..utils import _validate_type, fill_doc
 from ..defaults import _handle_default
 from ..io.meas_info import create_info
-from ..io.pick import (pick_types, _picks_to_idx, _DATA_CH_TYPES_ORDER_DEFAULT)
+from ..io.pick import pick_types, _picks_to_idx
 from ..time_frequency.psd import psd_multitaper
-from ..utils import _reject_data_segments
+from ..utils import _reject_data_segments, verbose
 
 
 @fill_doc
@@ -84,16 +81,11 @@ def plot_ica_sources(ica, inst, picks=None, start=None,
     exclude = ica.exclude
     picks = _picks_to_idx(ica.n_components_, picks, 'all')
 
-    if isinstance(inst, BaseRaw):
-        fig = _plot_sources_raw(ica, inst, picks, exclude, start=start,
-                                stop=stop, show=show, title=title,
-                                block=block, show_first_samp=show_first_samp,
-                                show_scrollbars=show_scrollbars)
-    elif isinstance(inst, BaseEpochs):
-        fig = _plot_sources_epochs(ica, inst, picks, exclude, start=start,
-                                   stop=stop, show=show, title=title,
-                                   block=block,
-                                   show_scrollbars=show_scrollbars)
+    if isinstance(inst, (BaseRaw, BaseEpochs)):
+        fig = _plot_sources(ica, inst, picks, exclude, start=start, stop=stop,
+                            show=show, title=title, block=block,
+                            show_first_samp=show_first_samp,
+                            show_scrollbars=show_scrollbars)
     elif isinstance(inst, Evoked):
         if start is not None or stop is not None:
             inst = inst.copy().crop(start, stop)
@@ -107,12 +99,15 @@ def plot_ica_sources(ica, inst, picks=None, start=None,
     return fig
 
 
-def _create_properties_layout(figsize=None):
+def _create_properties_layout(figsize=None, fig=None):
     """Create main figure and axes layout used by plot_ica_properties."""
     import matplotlib.pyplot as plt
+    if fig is not None and figsize is not None:
+        raise ValueError('Cannot specify both fig and figsize.')
     if figsize is None:
         figsize = [7., 6.]
-    fig = plt.figure(figsize=figsize, facecolor=[0.95] * 3)
+    if fig is None:
+        fig = plt.figure(figsize=figsize, facecolor=[0.95] * 3)
 
     axes_params = (('topomap', [0.08, 0.5, 0.3, 0.45]),
                    ('image', [0.5, 0.6, 0.45, 0.35]),
@@ -255,11 +250,11 @@ def _get_psd_label_and_std(this_psd, dB, ica, num_std):
     return psd_ylabel, psds_mean, spectrum_std
 
 
-@fill_doc
+@verbose
 def plot_ica_properties(ica, inst, picks=None, axes=None, dB=True,
                         plot_std=True, topomap_args=None, image_args=None,
                         psd_args=None, figsize=None, show=True, reject='auto',
-                        reject_by_annotation=True):
+                        reject_by_annotation=True, *, verbose=None):
     """Display component properties.
 
     Properties include the topography, epochs image, ERP/ERF, power
@@ -313,6 +308,7 @@ def plot_ica_properties(ica, inst, picks=None, axes=None, dB=True,
     %(reject_by_annotation_raw)s
 
         .. versionadded:: 0.21.0
+    %(verbose)s
 
     Returns
     -------
@@ -332,14 +328,12 @@ def plot_ica_properties(ica, inst, picks=None, axes=None, dB=True,
     # -------------------------
     _validate_type(inst, (BaseRaw, BaseEpochs), "inst", "Raw or Epochs")
     _validate_type(ica, ICA, "ica", "ICA")
+    _validate_type(plot_std, (bool, 'numeric'), 'plot_std')
     if isinstance(plot_std, bool):
         num_std = 1. if plot_std else 0.
-    elif isinstance(plot_std, (float, int)):
-        num_std = plot_std
-        plot_std = True
     else:
-        raise ValueError('plot_std has to be a bool, int or float, '
-                         'got %s instead' % type(plot_std))
+        plot_std = True
+    num_std = float(plot_std)
 
     # if no picks given - plot the first 5 components
     limit = min(5, ica.n_components_) if picks is None else len(ica.ch_names)
@@ -399,12 +393,14 @@ def plot_ica_properties(ica, inst, picks=None, axes=None, dB=True,
             duration=2,
             preload=True,
             reject_by_annotation=reject_by_annotation,
+            proj=False,
             verbose=False)
         inst = make_fixed_length_epochs(
             inst,
             duration=2,
             preload=True,
             reject_by_annotation=reject_by_annotation,
+            proj=False,
             verbose=False)
         kind = "Segment"
     else:
@@ -568,10 +564,7 @@ def _plot_ica_sources_evoked(evoked, picks, exclude, title, show, ica,
         plt.legend(loc='best')
     tight_layout(fig=fig)
 
-    # for old matplotlib, we actually need this to have a bounding
-    # box (!), so we have to put some valid text here, change
-    # alpha and  path effects later
-    texts.append(ax.text(0, 0, 'blank', zorder=3,
+    texts.append(ax.text(0, 0, '', zorder=3,
                          verticalalignment='baseline',
                          horizontalalignment='left',
                          fontweight='bold', alpha=0))
@@ -719,7 +712,7 @@ def plot_ica_scores(ica, scores, exclude=None, labels=None, axhline=None,
 
 @fill_doc
 def plot_ica_overlay(ica, inst, exclude=None, picks=None, start=None,
-                     stop=None, title=None, show=True):
+                     stop=None, title=None, show=True, n_pca_components=None):
     """Overlay of raw and cleaned signals given the unmixing matrix.
 
     This method helps visualizing signal quality and artifact rejection.
@@ -747,6 +740,9 @@ def plot_ica_overlay(ica, inst, exclude=None, picks=None, start=None,
         The figure title.
     show : bool
         Show figure if True.
+    %(n_pca_components_apply)s
+
+        .. versionadded:: 0.22
 
     Returns
     -------
@@ -778,17 +774,20 @@ def plot_ica_overlay(ica, inst, exclude=None, picks=None, start=None,
         data, times = inst[picks, start_compare:stop_compare]
 
         raw_cln = ica.apply(inst.copy(), exclude=exclude,
-                            start=start, stop=stop)
+                            start=start, stop=stop,
+                            n_pca_components=n_pca_components)
         data_cln, _ = raw_cln[picks, start_compare:stop_compare]
         fig = _plot_ica_overlay_raw(data=data, data_cln=data_cln,
                                     times=times, title=title,
                                     ch_types_used=ch_types_used, show=show)
-    elif isinstance(inst, Evoked):
+    else:
+        assert isinstance(inst, Evoked)
         inst = inst.copy().crop(start, stop)
         if picks is not None:
             inst.info['comps'] = []  # can be safely disabled
             inst.pick_channels([inst.ch_names[p] for p in picks])
-        evoked_cln = ica.apply(inst.copy(), exclude=exclude)
+        evoked_cln = ica.apply(inst.copy(), exclude=exclude,
+                               n_pca_components=n_pca_components)
         fig = _plot_ica_overlay_evoked(evoked=inst, evoked_cln=evoked_cln,
                                        title=title, show=show)
 
@@ -886,248 +885,166 @@ def _plot_ica_overlay_evoked(evoked, evoked_cln, title, show):
     return fig
 
 
-def _plot_sources_raw(ica, raw, picks, exclude, start, stop, show, title,
-                      block, show_first_samp, show_scrollbars):
-    """Plot the ICA components as raw array."""
+def _plot_sources(ica, inst, picks, exclude, start, stop, show, title, block,
+                  show_scrollbars, show_first_samp):
+    """Plot the ICA components as a RawArray or EpochsArray."""
+    from ._figure import _browse_figure
+    from .. import EpochsArray, BaseEpochs
+    from ..io import RawArray, BaseRaw
+
+    # handle defaults / check arg validity
+    is_raw = isinstance(inst, BaseRaw)
+    is_epo = isinstance(inst, BaseEpochs)
+    sfreq = inst.info['sfreq']
     color = _handle_default('color', (0., 0., 0.))
-    orig_data = ica._transform_raw(raw, 0, len(raw.times)) * 0.2
-    types = ['misc' for _ in picks]
-    eog_chs = pick_types(raw.info, meg=False, eog=True, ref_meg=False)
-    ecg_chs = pick_types(raw.info, meg=False, ecg=True, ref_meg=False)
-    data = [orig_data[pick] for pick in picks]
-    c_names = list(ica._ica_names)  # new list
+    units = _handle_default('units', None)
+    scalings = (_compute_scalings(None, inst) if is_raw else
+                _handle_default('scalings_plot_raw'))
+    scalings['misc'] = 5.
+    scalings['whitened'] = 1.
+    unit_scalings = _handle_default('scalings', None)
+
+    # data
+    if is_raw:
+        data = ica._transform_raw(inst, 0, len(inst.times))[picks]
+    else:
+        data = ica._transform_epochs(inst, concatenate=True)[picks]
+
+    # events
+    if is_epo:
+        event_id_rev = {v: k for k, v in inst.event_id.items()}
+        event_nums = inst.events[:, 2]
+        event_color_dict = _make_event_color_dict(None, inst.events,
+                                                  inst.event_id)
+
+    # channel properties / trace order / picks
+    ch_names = list(ica._ica_names)  # copy
+    ch_types = ['misc' for _ in picks]
+
+    # add EOG/ECG channels if present
+    eog_chs = pick_types(inst.info, meg=False, eog=True, ref_meg=False)
+    ecg_chs = pick_types(inst.info, meg=False, ecg=True, ref_meg=False)
     for eog_idx in eog_chs:
-        c_names.append(raw.ch_names[eog_idx])
-        types.append('eog')
+        ch_names.append(inst.ch_names[eog_idx])
+        ch_types.append('eog')
     for ecg_idx in ecg_chs:
-        c_names.append(raw.ch_names[ecg_idx])
-        types.append('ecg')
-    extra_picks = np.append(eog_chs, ecg_chs).astype(int)
-    if len(extra_picks) > 0:
-        eog_ecg_data, _ = raw[extra_picks, :]
-        for idx in range(len(eog_ecg_data)):
-            if idx < len(eog_chs):
-                eog_ecg_data[idx] /= 150e-6  # scaling for eog
-            else:
-                eog_ecg_data[idx] /= 5e-4  # scaling for ecg
+        ch_names.append(inst.ch_names[ecg_idx])
+        ch_types.append('ecg')
+    extra_picks = np.concatenate((eog_chs, ecg_chs)).astype(int)
+    if len(extra_picks):
+        if is_raw:
+            eog_ecg_data, _ = inst[extra_picks, :]
+        else:
+            eog_ecg_data = np.concatenate(inst.get_data(extra_picks), axis=1)
         data = np.append(data, eog_ecg_data, axis=0)
+    picks = np.concatenate(
+        (picks, ica.n_components_ + np.arange(len(extra_picks))))
+    ch_order = np.arange(len(picks))
+    n_channels = min([20, len(picks)])
 
-    for idx in range(len(extra_picks)):
-        picks = np.append(picks, ica.n_components_ + idx)
-    if title is None:
-        title = 'ICA components'
-    info = create_info([c_names[x] for x in picks], raw.info['sfreq'])
+    # create info
+    info = create_info([ch_names[x] for x in picks], sfreq, ch_types=ch_types)
+    info['meas_date'] = inst.info['meas_date']
+    info['bads'] = [ch_names[x] for x in exclude]
+    if is_raw:
+        inst_array = RawArray(data, info, inst.first_samp)
+        inst_array.set_annotations(inst.annotations)
+    else:
+        data = data.reshape(-1, len(inst), len(inst.times)).swapaxes(0, 1)
+        inst_array = EpochsArray(data, info)
 
-    info['bads'] = [c_names[x] for x in exclude]
-    if start is None:
-        start = 0
-    if stop is None:
-        stop = start + 20
-        stop = min(stop, raw.times[-1])
-    duration = stop - start
+    # handle time dimension
+    start = 0 if start is None else start
+    _last = inst.times[-1] if is_raw else len(inst.events)
+    stop = min(start + 20, _last) if stop is None else stop
+    first_time = inst._first_time if show_first_samp else 0
+    if is_raw:
+        duration = stop - start
+        start += first_time
+    else:
+        n_epochs = stop - start
+        total_epochs = len(inst)
+        epoch_n_times = len(inst.times)
+        n_epochs = min(n_epochs, total_epochs)
+        n_times = total_epochs * epoch_n_times
+        duration = n_epochs * epoch_n_times / sfreq
+        event_times = (np.arange(total_epochs) * epoch_n_times
+                       + inst.time_as_index(0)) / sfreq
+        # NB: this includes start and end of data:
+        boundary_times = np.arange(total_epochs + 1) * epoch_n_times / sfreq
     if duration <= 0:
         raise RuntimeError('Stop must be larger than start.')
-    t_end = int(duration * raw.info['sfreq'])
-    times = raw.times[0:t_end]
-    bad_color = (1., 0., 0.)
-    inds = list(range(len(picks)))
-    data = np.array(data)
-    n_channels = min([20, len(picks)])
-    first_time = raw._first_time if show_first_samp else 0
-    start += first_time
-    params = dict(raw=raw, orig_data=data, data=data[:, 0:t_end], inds=inds,
-                  ch_start=0, t_start=start, info=info, duration=duration,
-                  ica=ica, n_channels=n_channels, times=times, types=types,
-                  n_times=raw.n_times, bad_color=bad_color, picks=picks,
-                  first_time=first_time, data_picks=[], decim=1,
-                  noise_cov=None, whitened_ch_names=(), clipping=None,
-                  added_label=list(), show_scrollbars=show_scrollbars,
-                  show_scalebars=False)
-    _prepare_mne_browse_raw(params, title, 'w', color, bad_color, inds,
-                            n_channels)
-    params['scale_factor'] = 1.0
-    params['plot_fun'] = partial(_plot_raw_traces, params=params, color=color,
-                                 bad_color=bad_color)
-    _plot_annotations(raw, params)
-    params['update_fun'] = partial(_update_data, params)
-    params['pick_bads_fun'] = partial(_pick_bads, params=params)
-    params['label_click_fun'] = partial(_label_clicked, params=params)
-    # callbacks
-    callback_key = partial(_plot_raw_onkey, params=params)
-    params['fig'].canvas.mpl_connect('key_press_event', callback_key)
-    callback_scroll = partial(_plot_raw_onscroll, params=params)
-    params['fig'].canvas.mpl_connect('scroll_event', callback_scroll)
-    callback_pick = partial(_mouse_click, params=params)
-    params['fig'].canvas.mpl_connect('button_press_event', callback_pick)
-    callback_close = partial(_close_event, params=params)
-    params['fig'].canvas.mpl_connect('close_event', callback_close)
-    params['fig_proj'] = None
-    params['event_times'] = None
-    params['butterfly'] = False
-    params['update_fun']()
-    params['plot_fun']()
-    try:
-        plt_show(show, block=block)
-    except TypeError:  # not all versions have this
-        plt_show(show)
-    return params['fig']
 
+    # misc
+    bad_color = (0.8, 0.8, 0.8)
+    title = 'ICA components' if title is None else title
 
-def _update_data(params):
-    """Prepare the data on horizontal shift of the viewport."""
-    sfreq = params['info']['sfreq']
-    start = int((params['t_start'] - params['first_time']) * sfreq)
-    end = int((params['t_start'] + params['duration']) * sfreq)
-    params['data'] = params['orig_data'][:, start:end]
-    params['times'] = params['raw'].times[start:end]
+    params = dict(inst=inst_array,
+                  ica=ica,
+                  ica_inst=inst,
+                  info=info,
+                  # channels and channel order
+                  ch_names=np.array(ch_names),
+                  ch_types=np.array(ch_types),
+                  ch_order=ch_order,
+                  picks=picks,
+                  n_channels=n_channels,
+                  picks_data=list(),
+                  # time
+                  t_start=start if is_raw else boundary_times[start],
+                  duration=duration,
+                  n_times=inst.n_times if is_raw else n_times,
+                  first_time=first_time,
+                  decim=1,
+                  # events
+                  event_times=None if is_raw else event_times,
+                  # preprocessing
+                  projs=list(),
+                  projs_on=np.array([], dtype=bool),
+                  apply_proj=False,
+                  remove_dc=True,  # for EOG/ECG
+                  filter_coefs=None,
+                  filter_bounds=None,
+                  noise_cov=None,
+                  # scalings
+                  scalings=scalings,
+                  units=units,
+                  unit_scalings=unit_scalings,
+                  # colors
+                  ch_color_bad=bad_color,
+                  ch_color_dict=color,
+                  # display
+                  butterfly=False,
+                  clipping=None,
+                  scrollbars_visible=show_scrollbars,
+                  scalebars_visible=False,
+                  window_title=title)
+    if is_epo:
+        params.update(n_epochs=n_epochs,
+                      boundary_times=boundary_times,
+                      event_id_rev=event_id_rev,
+                      event_color_dict=event_color_dict,
+                      event_nums=event_nums,
+                      epoch_color_bad=(1, 0, 0),
+                      epoch_colors=None,
+                      xlabel='Epoch number')
+    fig = _browse_figure(**params)
+    fig._update_picks()
 
+    # update data, and plot
+    fig._update_trace_offsets()
+    fig._update_data()
+    fig._draw_traces()
 
-def _pick_bads(event, params):
-    """Select components on click."""
-    bads = params['info']['bads']
-    params['info']['bads'] = _select_bads(event, params, bads)
-    params['update_fun']()
-    params['plot_fun']()
+    # plot annotations (if any)
+    if is_raw:
+        fig._setup_annotation_colors()
+        fig._update_annotation_segments()
+        fig._draw_annotations()
 
+    # for blitting
+    fig.canvas.flush_events()
+    fig.mne.bg = fig.canvas.copy_from_bbox(fig.bbox)
 
-def _close_event(events, params):
-    """Exclude the selected components on close."""
-    info = params['info']
-    exclude = [params['ica']._ica_names.index(x)
-               for x in info['bads'] if x.startswith('ICA')]
-    params['ica'].exclude = exclude
-
-
-def _plot_sources_epochs(ica, epochs, picks, exclude, start, stop, show,
-                         title, block, show_scrollbars):
-    """Plot the components as epochs."""
-    data = ica._transform_epochs(epochs, concatenate=True)
-    eog_chs = pick_types(epochs.info, meg=False, eog=True, ref_meg=False)
-    ecg_chs = pick_types(epochs.info, meg=False, ecg=True, ref_meg=False)
-    c_names = list(ica._ica_names)
-    ch_types = np.repeat('misc', ica.n_components_)
-    for eog_idx in eog_chs:
-        c_names.append(epochs.ch_names[eog_idx])
-        ch_types = np.append(ch_types, 'eog')
-    for ecg_idx in ecg_chs:
-        c_names.append(epochs.ch_names[ecg_idx])
-        ch_types = np.append(ch_types, 'ecg')
-    extra_picks = np.append(eog_chs, ecg_chs).astype(int)
-    if len(extra_picks) > 0:
-        eog_ecg_data = np.concatenate(epochs.get_data()[:, extra_picks],
-                                      axis=1)
-        data = np.append(data, eog_ecg_data, axis=0)
-    scalings = _handle_default('scalings_plot_raw')
-    scalings['misc'] = 5.0
-    info = create_info(ch_names=c_names, sfreq=epochs.info['sfreq'],
-                       ch_types=ch_types)
-    info['projs'] = list()
-    info['bads'] = [c_names[x] for x in exclude]
-    if title is None:
-        title = 'ICA components'
-    if start is None:
-        start = 0
-    if stop is None:
-        stop = start + 20
-        stop = min(stop, len(epochs.events))
-    for idx in range(len(extra_picks)):
-        picks = np.append(picks, ica.n_components_ + idx)
-    n_epochs = stop - start
-    if n_epochs <= 0:
-        raise RuntimeError('Stop must be larger than start.')
-    params = dict(ica=ica, epochs=epochs, info=info, orig_data=data,
-                  bads=list(), bad_color=(1., 0., 0.),
-                  t_start=start * len(epochs.times),
-                  data_picks=list(), decim=1, whitened_ch_names=(),
-                  noise_cov=None, show_scrollbars=show_scrollbars,
-                  epoch_colors=None)
-    params['label_click_fun'] = partial(_label_clicked, params=params)
-    # changing the order to 'misc' before 'eog' and 'ecg'
-    order = list(_DATA_CH_TYPES_ORDER_DEFAULT)
-    order.pop(order.index('misc'))
-    order.insert(order.index('eog'), 'misc')
-    _prepare_mne_browse_epochs(params, projs=list(), n_channels=20,
-                               n_epochs=n_epochs, scalings=scalings,
-                               title=title, picks=picks,
-                               order=order, info=info)
-    params['plot_update_proj_callback'] = _update_epoch_data
-    _update_epoch_data(params)
-    params['hsel_patch'].set_x(params['t_start'])
-    callback_close = partial(_close_epochs_event, params=params)
-    params['fig'].canvas.mpl_connect('close_event', callback_close)
-    try:
-        plt_show(show, block=block)
-    except TypeError:  # not all versions have this
-        plt_show(show)
-    return params['fig']
-
-
-def _update_epoch_data(params):
-    """Prepare the data on horizontal shift."""
-    start = params['t_start']
-    n_epochs = params['n_epochs']
-    end = start + n_epochs * len(params['epochs'].times)
-    data = params['orig_data'][:, start:end]
-    types = params['types']
-    for pick, ind in enumerate(params['inds']):
-        params['data'][pick] = data[ind] / params['scalings'][types[pick]]
-    params['plot_fun']()
-
-
-def _close_epochs_event(events, params):
-    """Exclude the selected components on close."""
-    info = params['info']
-    exclude = [info['ch_names'].index(x) for x in info['bads']
-               if x.startswith('IC')]
-    params['ica'].exclude = exclude
-
-
-def _label_clicked(pos, params):
-    """Plot independent components on click to label."""
-    import matplotlib.pyplot as plt
-    offsets = np.array(params['offsets']) + params['offsets'][0]
-    line_idx = np.searchsorted(offsets, pos[1]) + params['ch_start']
-    if line_idx >= len(params['picks']):
-        return
-    ic_idx = [params['picks'][line_idx]]
-    if params['types'][line_idx] != 'misc':
-        warn('Can only plot ICA components.')
-        return
-    types = list()
-    info = params['ica'].info
-    if len(pick_types(info, meg=False, eeg=True, ref_meg=False)) > 0:
-        types.append('eeg')
-    if len(pick_types(info, meg='mag', ref_meg=False)) > 0:
-        types.append('mag')
-    if len(pick_types(info, meg='grad', ref_meg=False)) > 0:
-        types.append('grad')
-
-    ica = params['ica']
-    data = np.dot(ica.mixing_matrix_[:, ic_idx].T,
-                  ica.pca_components_[:ica.n_components_])
-    data = np.atleast_2d(data)
-    fig, axes, _, _ = _prepare_trellis(len(types), ncols=3)
-    for ch_idx, ch_type in enumerate(types):
-        try:
-            data_picks, pos, merge_channels, _, _, this_sphere, clip_origin = \
-                _prepare_topomap_plot(ica, ch_type)
-        except Exception as exc:
-            warn(str(exc))
-            plt.close(fig)
-            return
-        outlines = _make_head_outlines(this_sphere, pos, 'head', clip_origin)
-        this_data = data[:, data_picks]
-        ax = axes[ch_idx]
-        if merge_channels:
-            from ..channels.layout import _merge_ch_data
-        for ii, data_ in zip(ic_idx, this_data):
-            ax.set_title('%s %s' % (ica._ica_names[ii], ch_type), fontsize=12)
-            if merge_channels:
-                data_, _ = _merge_ch_data(data_, 'grad', [])
-            plot_topomap(data_.flatten(), pos, axes=ax, show=False,
-                         sphere=this_sphere, outlines=outlines)
-            _hide_frame(ax)
-    tight_layout(fig=fig)
-    fig.subplots_adjust(top=0.88, bottom=0.)
-    fig.canvas.draw()
-    plt_show(True)
+    plt_show(show, block=block)
+    return fig
